Name:          openstack-savanna
Version:       2014.1.b3
Release:       2%{?dist}
Summary:       Apache Hadoop cluster management on OpenStack
License:       ASL 2.0
URL:           https://launchpad.net/savanna
Source0:       http://tarballs.openstack.org/savanna/savanna-%{version}.tar.gz
Source1:       openstack-savanna-api.init
Patch0:        sqlalchemy0.7-magic.patch
BuildArch:     noarch

BuildRequires: python2-devel
BuildRequires: python-setuptools
BuildRequires: python-sphinxcontrib-httpdomain
BuildRequires: python-pbr >= 0.5.19
# Needed by sqlalchemy0.7-magic.patch
BuildRequires: python-sqlalchemy0.7
BuildRequires: python-paste-deploy1.5
# Needed by check
#BuildRequires: python-unittest2
#BuildRequires: python-mock

Requires: python-alembic
#?Babel>=1.3?
Requires: python-eventlet
Requires: python-flask
Requires: python-iso8601
Requires: python-jsonschema >= 1.3.0
Requires: python-oslo-config >= 1.2.0
Requires: python-oslo-messaging
Requires: python-paramiko >= 1.9.0
Requires: python-pbr
Requires: python-cinderclient >= 1.0.5
Requires: python-keystoneclient >= 0.6.0
Requires: python-novaclient >= 2.15.0
Requires: python-swiftclient
Requires: python-neutronclient
Requires: python-six >= 1.4.1
Requires: python-stevedore >= 0.14
Requires: python-sqlalchemy0.7
Requires: python-webob

Requires(post):   chkconfig
Requires(preun):  initscripts
Requires(postun): chkconfig
Requires(pre):    shadow-utils


%description
Savanna provides the ability to elastically manage Apache Hadoop
clusters on OpenStack.


%prep
%setup -q -n savanna-%{version}
%patch0
rm -rf savanna.egg-info
rm -f {test-,}requirements.txt
sed -i 's/0.5.21/0.5.19/' setup.py
# The data_files glob appears broken in pbr 0.5.19, so be explicit
sed -i 's,etc/savanna/\*,etc/savanna/savanna.conf.sample,' setup.cfg


%build
%{__python} setup.py build

export PYTHONPATH=$PWD:${PYTHONPATH}
# Note: json warnings likely resolved w/ pygments 1.5 (not yet in Fedora)
#sphinx-1.0-build doc/source html
#rm -rf html/.{doctrees,buildinfo}


%install
%{__python} setup.py install --skip-build --root %{buildroot}

install -d -m 755 %{buildroot}%{_localstatedir}/run/savanna
install -p -D -m 755 %{SOURCE1} %{buildroot}%{_initrddir}/openstack-savanna-api

HOME=%{_sharedstatedir}/savanna
install -d -m 700 %{buildroot}$HOME

# TODO: os_admin_username/password/tenant_name
SAMPLE=%{buildroot}%{_datadir}/savanna/savanna.conf.sample
CONF=%{buildroot}%{_sysconfdir}/savanna/savanna.conf
install -d -m 755 $(dirname $CONF)
install -D -m 640 $SAMPLE $CONF
sed -i -e "s,.*connection=.*,connection=sqlite:///$HOME/savanna-server.db," $CONF

# Do not package tests
rm -rf %{buildroot}%{python_sitelib}/savanna/tests

mkdir -p -m0755 %{buildroot}/%{_var}/log/savanna


#%%check
#%%{__python} setup.py test


%pre
# Origin: http://fedoraproject.org/wiki/Packaging:UsersAndGroups#Dynamic_allocation
USERNAME=savanna
GROUPNAME=$USERNAME
HOMEDIR=%{_sharedstatedir}/savanna
getent group $GROUPNAME >/dev/null || groupadd -r $GROUPNAME
getent passwd $USERNAME >/dev/null || \
  useradd -r -g $GROUPNAME -G $GROUPNAME -d $HOMEDIR -s /sbin/nologin \
  -c "Savanna Daemons" $USERNAME
exit 0


%post
# TODO: if db file then savanna-db-manage update head
# TODO: savanna-db-manage should read /etc/savanna/savanna.conf by default
#       https://bugs.launchpad.net/savanna/+bug/1202227
/sbin/chkconfig --add openstack-savanna-api


%preun
if [ $1 -eq 0 ] ; then
   /sbin/service openstack-savanna-api stop >/dev/null 2>&1
   /sbin/chkconfig --del openstack-savanna-api
fi


%postun
if [ $1 -ge 1 ] ; then
   # Package upgrade, not uninstall
   /sbin/service openstack-savanna-api condrestart > /dev/null 2>&1 || :
fi


%files
#doc html README.rst LICENSE
%doc README.rst LICENSE
%dir %attr(0755, savanna, root) %{_localstatedir}/run/savanna
%dir %{_sysconfdir}/savanna
# Note: this file is not readable because it holds auth credentials
%config(noreplace) %attr(-, root, savanna) %{_sysconfdir}/savanna/savanna.conf
%{_bindir}/savanna-api
%{_bindir}/_savanna-subprocess
%{_bindir}/savanna-db-manage
%{_initrddir}/openstack-savanna-api
%dir %attr(-, savanna, savanna) %{_sharedstatedir}/savanna
# Note: permissions on savanna's home are intentially 0700
%dir %{_datadir}/savanna
%{_datadir}/savanna/savanna.conf.sample
%{python_sitelib}/savanna
%{python_sitelib}/savanna-%{version}-py?.?.egg-info
%defattr(-,savanna,savanna,-)
%dir %{_var}/log/savanna



%changelog
* Fri Mar 14 2014 Matthew Farrellee <matt@redhat> - 2014.1.b3-2
- Fixed python-webob dependency version

* Mon Mar 10 2014 Matthew Farrellee <matt@redhat> - 2014.1.b3-1
- 2014.1.b3 release

* Mon Jan 27 2014 Matthew Farrellee <matt@redhat> - 2014.1.b2-3
- Require stevedore >= 0.13

* Mon Jan 27 2014 Matthew Farrellee <matt@redhat> - 2014.1.b2-2
- Added space around paramiko requires

* Mon Jan 27 2014 Matthew Farrellee <matt@redhat> - 2014.1.b2-1
- 2014.1.b2 release

* Sat Jan 18 2014 Matthew Farrellee <matt@redhat> - 2014.1.b1-1
- 2014.1.b1 release

* Tue Oct 22 2013 Matthew Farrellee <matt@redhat> - 0.3-3
- Include Vanilla Plugin SQL files (for EDP)

* Mon Oct 21 2013 Matthew Farrellee <matt@redhat> - 0.3-2
- Fix db connection url

* Sat Oct 19 2013 Matthew Farrellee <matt@redhat> - 0.3-1
- 0.3 release
- Enable logging into /var/log/savanna

* Fri Oct 11 2013 Matthew Farrellee <matt@redhat> - 0.3-0.2
- 0.3 rc3 build
- Remove workaround patch for novaclient bug 1223934
- Remove spec infrastructure for master branch build
- Remove html generation until python-oslo-sphinx is available

* Wed Sep 18 2013 Matthew Farrellee <matt@redhat> - 0.3-0.1.a274.gabf778f
- Add workaround patch for novaclient bug 1223934

* Thu Sep 12 2013 Matthew Farrellee <matt@redhat> - 0.3-0.1.a252.ga1714e0
- Update to build and run post pbr addition and pycrypto removal
- Add removal of sdist egg
- Add magic patch to use SQLAlchemy0.7 on EL6
- Add workaround patch for novaclient bug 1223934

* Mon Aug 12 2013 Matthew Farrellee <matt@redhat> - 0.2-3
- Updates to build on EL6,
-  Use SysV init instead of systemd, copied from openstack-nova-api.init
-  Use python-sphinx10, it has sphinx.ext.viewcode

* Fri Aug 09 2013 Matthew Farrellee <matt@redhat> - 0.2-2
- Updates from package review BZ986615

* Mon Jul 15 2013 Matthew Farrellee <matt@redhat> - 0.2-1
- Initial package
